
## CATO-CLI - mutation.site.removeStaticHost:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.removeStaticHost) for documentation on this operation.

### Usage for mutation.site.removeStaticHost:

`catocli mutation site removeStaticHost -h`

`catocli mutation site removeStaticHost <json>`

`catocli mutation site removeStaticHost "$(cat < mutation.site.removeStaticHost.json)"`

`catocli mutation site removeStaticHost '{"hostId":"id"}'`


#### Operation Arguments for mutation.site.removeStaticHost ####

`accountId` [ID] - (required) N/A    
`hostId` [ID] - (required) N/A    
